//+------------------------------------------------------------------+
//|                                                 PositionInfo.mqh |
//|                      Copyright  2009, MetaQuotes Software Corp. |
//|                                       http://www.metaquotes.net/ |
//+------------------------------------------------------------------+
//+------------------------------------------------------------------+
//| Class CPositionInfo.                                             |
//| Appointment: Class for access to position info.                  |
//+------------------------------------------------------------------+
class CPositionInfo
  {
public:
   //--- fast access methods to the integer position propertyes
   datetime           Time();
   ENUM_POSITION_TYPE PositionType();
   string             PositionTypeDescription();
   //--- fast access methods to the double position propertyes
   double            Volume();
   double            PriceOpen();
   double            StopLoss();
   double            TakeProfit();
   double            PriceCurrent();
   double            Commission();
   double            Swap();
   double            Profit();
   //--- fast access methods to the string position propertyes
   string            Symbol();
   //--- access methods to the API MQL5 functions
   long              InfoInteger(ENUM_POSITION_PROPERTY_INTEGER prop_id);
   double            InfoDouble(ENUM_POSITION_PROPERTY_DOUBLE prop_id);
   string            InfoString(ENUM_POSITION_PROPERTY_STRING prop_id);
   //--- method for select position
   bool              Select(const string symbol);
  };
//+------------------------------------------------------------------+
//| Get the property value "POSITION_TIME".                          |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "POSITION_TIME".                      |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
datetime CPositionInfo::Time()
  {
   return((datetime)PositionGetInteger(POSITION_TIME));
  }
//+------------------------------------------------------------------+
//| Get the property value "POSITION_TYPE".                          |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "POSITION_TYPE".                      |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
ENUM_POSITION_TYPE CPositionInfo::PositionType()
  {
   return((ENUM_POSITION_TYPE)PositionGetInteger(POSITION_TYPE));
  }
//+------------------------------------------------------------------+
//| Get the property value "POSITION_TYPE" as string.                |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "POSITION_TYPE" as string.            |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
string CPositionInfo::PositionTypeDescription()
  {
   string str;
//---
   switch(PositionType())
     {
      case POSITION_TYPE_BUY:
         str="Buy";
         break;
      case POSITION_TYPE_SELL:
         str="Sell";
         break;
      default:
         str="Unknown type";
     }
//---
   return(str);
  }
//+------------------------------------------------------------------+
//| Get the property value "POSITION_VOLUME".                        |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "POSITION_VOLUME".                    |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
double CPositionInfo::Volume()
  {
   return(PositionGetDouble(POSITION_VOLUME));
  }
//+------------------------------------------------------------------+
//| Get the property value "POSITION_PRICE_OPEN".                    |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "POSITION_PRICE_OPEN".                |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
double CPositionInfo::PriceOpen()
  {
   return(PositionGetDouble(POSITION_PRICE_OPEN));
  }
//+------------------------------------------------------------------+
//| Get the property value "POSITION_SL".                            |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "POSITION_SL".                        |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
double CPositionInfo::StopLoss()
  {
   return(PositionGetDouble(POSITION_SL));
  }
//+------------------------------------------------------------------+
//| Get the property value "POSITION_TP".                            |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "POSITION_TP".                        |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
double CPositionInfo::TakeProfit()
  {
   return(PositionGetDouble(POSITION_TP));
  }
//+------------------------------------------------------------------+
//| Get the property value "POSITION_PRICE_CURRENT".                 |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "POSITION_PRICE_CURRENT".             |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
double CPositionInfo::PriceCurrent()
  {
   return(PositionGetDouble(POSITION_PRICE_CURRENT));
  }
//+------------------------------------------------------------------+
//| Get the property value "POSITION_COMMISSION".                    |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "POSITION_COMMISSION".                |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
double CPositionInfo::Commission()
  {
   return(PositionGetDouble(POSITION_COMMISSION));
  }
//+------------------------------------------------------------------+
//| Get the property value "POSITION_SWAP".                          |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "POSITION_SWAP".                      |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
double CPositionInfo::Swap()
  {
   return(PositionGetDouble(POSITION_SWAP));
  }
//+------------------------------------------------------------------+
//| Get the property value "POSITION_PROFIT".                        |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "POSITION_PROFIT".                    |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
double CPositionInfo::Profit()
  {
   return(PositionGetDouble(POSITION_PROFIT));
  }
//+------------------------------------------------------------------+
//| Get the property value "POSITION_SYMBOL".                        |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "POSITION_SYMBOL".                    |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
string CPositionInfo::Symbol()
  {
   return(PositionGetString(POSITION_SYMBOL));
  }
//+------------------------------------------------------------------+
//| Access functions PositionGetInteger(...).                        |
//| INPUT:  prop_id  -identifier integer properties.                 |
//| OUTPUT: the integer property value.                              |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
long CPositionInfo::InfoInteger(ENUM_POSITION_PROPERTY_INTEGER prop_id)
  {
   return(PositionGetInteger(prop_id));
  }
//+------------------------------------------------------------------+
//| Access functions PositionGetDouble(...).                         |
//| INPUT:  prop_id  -identifier double properties.                  |
//| OUTPUT: the double property value.                               |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
double CPositionInfo::InfoDouble(ENUM_POSITION_PROPERTY_DOUBLE prop_id)
  {
   return(PositionGetDouble(prop_id));
  }
//+------------------------------------------------------------------+
//| Access functions PositionGetString(...).                         |
//| INPUT:  prop_id  -identifier string properties.                  |
//| OUTPUT: the string property value.                               |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
string CPositionInfo::InfoString(ENUM_POSITION_PROPERTY_STRING prop_id)
  {
   return(PositionGetString(prop_id));
  }
//+------------------------------------------------------------------+
//| Access functions PositionSelect(...).                            |
//| INPUT:  symbol -symbol name for select position.                 |
//| OUTPUT: true-if successful, false otherwise.                     |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
bool CPositionInfo::Select(const string symbol)
  {
   return(PositionSelect(symbol));
  }
//+------------------------------------------------------------------+
